Area28
=======================================================================================================================

Development and collaboration platform providing a means to communicate ...

This is the documentation of our repository `development kit <https://gitlab.com/area28/app/devkit>`_.

Features
-----------------------------------------------------------------------------------------------------------------------

Contents
-----------------------------------------------------------------------------------------------------------------------

The documentation is organized in five parts:

- **GET STARTED** contains a quick tour, the installation instructions and some useful information about our philosophy
  and a glossary.
- **USING 🤗 Area28devkit** contains general tutorials on how to use the library.
- **ADVANCED GUIDES** contains more advanced guides that are more specific to a given script or part of the library.
- The three last section contain the documentation of each public class and function, grouped in:

    - **MAIN CLASSES** for the main classes exposing the important APIs of the library.
    - **MODELS** for the classes and functions related to each interface implemented in the library.
    - **INTERNAL HELPERS** for the classes and functions we use internally.

..
    This list is updated automatically from the README with `make fix-copies`. Do not update manually!
